# -*- encoding: utf-8 -*-

import copy

try:
    from django.core.urlresolvers import reverse
except ImportError:
    from django.urls import reverse

from django.db import transaction
from django.http.response import Http404
from django.views.generic import RedirectView

from bpp.models.patent import Patent, Patent_Autor
from bpp.models.wydawnictwo_ciagle import Wydawnictwo_Ciagle, Wydawnictwo_Ciagle_Autor
from bpp.models.wydawnictwo_zwarte import Wydawnictwo_Zwarte, Wydawnictwo_Zwarte_Autor


class TozView(RedirectView):
    @transaction.atomic
    def get_redirect_url(self, pk):
        try:
            w = self.klass.objects.get(pk=pk)
        except self.klass.DoesNotExist:
            raise Http404

        w_copy = copy.copy(w)
        w_copy.id = None
        w_copy.tytul_oryginalny = "[ ** KOPIA ** ]" + w_copy.tytul_oryginalny
        w_copy.slug = None
        w_copy.save()

        for wca in self.klass_autor.objects.filter(rekord=w):
            wca_copy = copy.copy(wca)
            wca_copy.id = None
            wca_copy.rekord = w_copy
            wca_copy.save()

        return reverse("admin:bpp_%s_change" % self.klass_name, args=(w_copy.pk,))


class WydawnictwoCiagleTozView(TozView):
    klass = Wydawnictwo_Ciagle
    klass_autor = Wydawnictwo_Ciagle_Autor
    klass_name = "wydawnictwo_ciagle"


class WydawnictwoZwarteTozView(TozView):
    klass = Wydawnictwo_Zwarte
    klass_autor = Wydawnictwo_Zwarte_Autor
    klass_name = "wydawnictwo_zwarte"


class PatentTozView(TozView):
    klass = Patent
    klass_autor = Patent_Autor
    klass_name = "patent"



from django.conf import settings
from django.core.exceptions import ValidationError
from django.db import models
from django.db.models import Q

from django.contrib.contenttypes.fields import GenericForeignKey
from django.contrib.contenttypes.models import ContentType

from bpp.models import Autor_Dyscyplina, Uczelnia
from bpp.models.abstract import (
    BazaModeluOdpowiedzialnosciAutorow,
    DwaTytuly,
    ModelZDOI,
    ModelZOplataZaPublikacje,
    ModelZRokiem,
)


class Zgloszenie_Publikacji(
    ModelZRokiem,
    DwaTytuly,
    ModelZDOI,
    ModelZOplataZaPublikacje,
):
    email = models.EmailField("E-mail zgłaszającego")

    utworzono = models.DateTimeField(
        "Utworzono", auto_now_add=True, blank=True, null=True
    )
    utworzyl = models.ForeignKey(
        settings.AUTH_USER_MODEL,
        models.CASCADE,
        verbose_name="Utworzył",
        null=True,
        blank=True,
    )

    ostatnio_zmieniony = models.DateTimeField(auto_now=True, null=True, db_index=True)

    object_id = models.BigIntegerField(null=True, blank=True)
    content_type = models.ForeignKey(
        ContentType, on_delete=models.SET_NULL, null=True, blank=True
    )
    odpowiednik_w_bpp = GenericForeignKey()

    kod_do_edycji = models.UUIDField(editable=False, unique=True, null=True, blank=True)
    przyczyna_zwrotu = models.TextField(blank=True, null=True)

    class Statusy(models.IntegerChoices):
        NOWY = 0, "nowe zgłoszenie"
        ZAAKCEPTOWANY = 1, "zaakceptowany - dodany do bazy BPP"
        WYMAGA_ZMIAN = 2, "wymaga zmian - odesłano do zgłaszającego"
        PO_ZMIANACH = 3, "zmiany naniesione przez zgłaszającego"
        ODRZUCONO = 4, "odrzucono w całości"
        SPAM = 5, "spam"

    status = models.PositiveSmallIntegerField(
        default=Statusy.NOWY, choices=Statusy.choices
    )

    class Rodzaje(models.IntegerChoices):
        ARTYKUL_LUB_MONOGRAFIA = 1, "artykuł naukowy lub monografia"
        POZOSTALE = 2, "pozostałe rodzaje"

    rodzaj_zglaszanej_publikacji = models.PositiveSmallIntegerField(
        "Rodzaj zgłaszanej publikacji",
        choices=Rodzaje.choices,
        help_text="Dla artykułów naukowych i monografii może być wymagane wprowadzenie informacji o opłatach"
        " za publikację w ostatnim etapie wypełniania formularza. ",
    )

    strona_www = models.URLField(
        "Dostępna w sieci pod adresem",
        help_text="Pole opcjonalne. Adres URL lokalizacji pełnego tekstu pracy (dostęp otwarty lub nie). "
        "Jeżeli praca posiada numer DOI, wpisz go w postaci adresu URL czyli https://dx.doi.org/[NUMER_DOI]. "
        "Jeżeli praca nie posiada numeru DOI bądź nie jest dostępna w sieci, pozostaw to pole puste. Adres "
        "URL musi być pełny, to znaczy musi zaczynać się od oznaczenia protokołu czyli od ciągu "
        "znaków http:// lub https:// ",
        max_length=1024,
        blank=True,
        null=True,
    )

    plik = models.FileField(
        "Plik załącznika",
        help_text="""Jeżeli zgłaszana publikacja nie jest dostępna nigdzie w sieci internet,
        prosimy o dodanie załącznika""",
        blank=True,
        null=True,
    )

    def clean(self):
        wpisano_informacje_o_oplatach = (
            self.opl_pub_cost_free is not None
            or self.opl_pub_research_potential is not None
            or self.opl_pub_research_or_development_projects is not None
            or self.opl_pub_other is not None
            or (self.opl_pub_amount is not None and self.opl_pub_amount != 0)
        )

        # Informacja o opłatach może być opcjonalna, w zależności od ustawień obiektu Uczelnia.
        # Informacja o opłatach może być opcjonalna jeżeli rodzaj zgłaszanej publikacji to "pozostałe"

        # W obydwu przypadkach nie walidujemy (nie uruchamiamy ModelZOplataZaPublikacje.clean)... ale pod jednym
        # warunkiem: pod takim warunkiem, ze NIC nie zostało wpisane jeżeli chodzi o informację o opłatach
        # -- czyli, że zmienna zupelny_brak_informacji_o_oplatach jest False.

        uczelnia = Uczelnia.objects.get_default()

        if uczelnia is not None and (
            uczelnia.wymagaj_informacji_o_oplatach is True
            or wpisano_informacje_o_oplatach
        ):
            # Administrator systemu wymaga informacji o opłatach dla artykułów i monografii
            if (
                self.rodzaj_zglaszanej_publikacji
                == Zgloszenie_Publikacji.Rodzaje.ARTYKUL_LUB_MONOGRAFIA
            ) or wpisano_informacje_o_oplatach:
                # Użytkownik zgłasza arytkuł lub monografię, uruchamiamy weryfikację
                ModelZOplataZaPublikacje.clean(self)

    def __str__(self):
        return f"Zgłoszenie od {self.email} utworzone {self.utworzono} dla pracy {self.tytul_oryginalny}"

    class Meta:
        verbose_name = "zgłoszenie publikacji"
        verbose_name_plural = "zgłoszenia publikacji"
        ordering = ("-ostatnio_zmieniony", "tytul_oryginalny")

    def moze_zostac_zwrocony(self):
        return self.status in [
            Zgloszenie_Publikacji.Statusy.NOWY,
            Zgloszenie_Publikacji.Statusy.PO_ZMIANACH,
        ]


class Zgloszenie_Publikacji_Autor(BazaModeluOdpowiedzialnosciAutorow):
    rekord = models.ForeignKey(Zgloszenie_Publikacji, on_delete=models.CASCADE)

    rok = models.PositiveSmallIntegerField()

    class Meta:
        verbose_name = "autor w zgłoszeniu publikacji"
        verbose_name_plural = "autorzy w zgłoszeniu publikacji"
        ordering = ("kolejnosc",)

    def __str__(self):
        return f"autor {self.autor} dla zgłoszenia publikacji {self.rekord.tytul_oryginalny}"

    def clean(self):

        if self.autor_id is None:
            raise ValidationError({"autor": "Wybierz jakiegoś autora"})

        przypisanie_na_rok_istnieje = Autor_Dyscyplina.objects.filter(
            autor=self.autor,
            rok=self.rok,
        ).exists()

        if przypisanie_na_rok_istnieje and self.dyscyplina_naukowa_id is None:
            raise ValidationError(
                {
                    "dyscyplina_naukowa": f"Autor {self.autor} ma przypisaną przynajmniej jedną dyscyplinę na rok "
                    f"{self.rok} i z tego powodu to pole nie może być puste. "
                }
            )

        if self.dyscyplina_naukowa is not None:
            try:
                Autor_Dyscyplina.objects.get(
                    Q(dyscyplina_naukowa=self.dyscyplina_naukowa)
                    | Q(subdyscyplina_naukowa=self.dyscyplina_naukowa),
                    autor=self.autor,
                    rok=self.rok,
                )
            except Autor_Dyscyplina.DoesNotExist:
                raise ValidationError(
                    {
                        "dyscyplina_naukowa": f"Autor {self.autor} nie ma przypisania na "
                        f"rok {self.rok} do dyscypliny {self.dyscyplina_naukowa}."
                    }
                )


class Obslugujacy_Zgloszenia_WydzialowManager(models.Manager):
    def emaile_dla_wydzialu(self, wydzial):

        # Jeżeli jest ktokolwiek przypisany do danego wydziału, to zwróć go:
        if self.filter(wydzial=wydzial).exists():
            ret = []
            for email in (
                self.filter(wydzial=wydzial)
                .values_list("user__email", flat=True)
                .distinct()
            ):
                if email != "" and email is not None and email != "brak@email.pl":
                    ret.append(email)

            if ret:
                return ret


class Obslugujacy_Zgloszenia_Wydzialow(models.Model):
    user = models.ForeignKey(
        settings.AUTH_USER_MODEL, models.CASCADE, verbose_name="Użytkownik"
    )
    wydzial = models.ForeignKey("bpp.Wydzial", models.CASCADE, verbose_name="Wydział")

    objects = Obslugujacy_Zgloszenia_WydzialowManager()

    class Meta:
        verbose_name = "obsługujący zgłoszenia dla wydziału"
        verbose_name_plural = "obsługujący zgłoszenia dla wydziałów"
        ordering = ("user__username", "wydzial__nazwa")
        unique_together = [("user", "wydzial")]



# -*- encoding: utf-8 -*-
import uuid
from datetime import datetime
import traceback
import sys

from django.conf import settings
from django.db import models
from django.db.models import CASCADE, UUIDField
# from django_extensions.db.fields import UUIDField
from django_extensions.db.fields.json import JSONField
from django.utils.translation import gettext_lazy as _
from zope.interface import classImplements

from celeryui import interfaces
from celeryui.interfaces import IReportMaker, IWebTask


TRACEBACK_MAX_LENGTH = 10240

REPORTS_PATH = 'report'


class Status:
    COMPLETED = _("completed")
    ERROR = _("error")
    IN_PROGRESS = _("in progress")
    WAITING = _("waiting")


class Report(models.Model):
    uid = UUIDField(unique=True, editable=False, blank=True, default=uuid.uuid4)

    function = models.TextField()
    arguments = JSONField(null=True, blank=True)

    ordered_by = models.ForeignKey(settings.AUTH_USER_MODEL, CASCADE)
    ordered_on = models.DateTimeField(auto_now_add=True)

    file = models.FileField(upload_to=REPORTS_PATH, null=True, blank=True)

    started_on = models.DateTimeField(null=True, blank=True)
    finished_on = models.DateTimeField(null=True, blank=True)

    # Progress in percent
    progress = models.FloatField(null=True, blank=True, default=0.0)

    error = models.BooleanField(default=False)
    traceback = models.TextField(
        max_length=TRACEBACK_MAX_LENGTH, null=True, blank=True)

    class Meta:
        ordering = ['-ordered_on']

    def status(self):
        if self.started_on is None:
            return Status.WAITING

        if self.finished_on is None:
            return Status.IN_PROGRESS

        if self.error:
            return Status.ERROR

        return Status.COMPLETED

    def started(self):
        self.started_on = datetime.now()
        self.progress = 0.0
        self.save()

    def finished_okay(self):
        """This report has been completed, mark it as finished.
        """
        self.finished_on = datetime.now()
        self.progress = 1.0
        self.save()

    def finished_with_error(self, exc_type, exc_value, exc_traceback):
        self.finished_on = datetime.now()
        self.error = True
        self.traceback = "\n".join(traceback.format_exception(
            exc_type, exc_value, exc_traceback, limit=TRACEBACK_MAX_LENGTH))
        self.save()

    def run_in_context(self, function, raise_exceptions=False):
        """Runs a function in context of curret report, which means: it sets
        the variables according to success or failure of a given function.
        """
        try:
            function()
            self.finished_okay()
        except Exception as e:
            exc_type, exc_value, exc_traceback = sys.exc_info()
            self.finished_with_error(exc_type, exc_value, exc_traceback)
            if raise_exceptions:
                raise exc_value.with_traceback(exc_traceback)

    def execute(self, raise_exceptions=False):
        self.run_in_context(
            IReportMaker(self).perform,
            raise_exceptions=raise_exceptions)

    def adapted(self):
        """Used as helper function in templates"""
        return IWebTask(self)

classImplements(Report, interfaces.IReport)



# -*- coding: utf-8 -*-


from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0028_openaccess'),
    ]

    operations = [
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='openaccess_czas_publikacji',
            field=models.ForeignKey(on_delete=models.CASCADE, blank=True, to='bpp.Czas_Udostepnienia_OpenAccess', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='openaccess_licencja',
            field=models.ForeignKey(on_delete=models.CASCADE, blank=True, to='bpp.Licencja_OpenAccess', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='openaccess_tryb_dostepu',
            field=models.ForeignKey(on_delete=models.CASCADE, blank=True, to='bpp.Tryb_OpenAccess_Wydawnictwo_Ciagle', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='wydawnictwo_ciagle',
            name='openaccess_wersja_tekstu',
            field=models.ForeignKey(on_delete=models.CASCADE, blank=True, to='bpp.Wersja_Tekstu_OpenAccess', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='openaccess_czas_publikacji',
            field=models.ForeignKey(on_delete=models.CASCADE, blank=True, to='bpp.Czas_Udostepnienia_OpenAccess', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='openaccess_licencja',
            field=models.ForeignKey(on_delete=models.CASCADE, blank=True, to='bpp.Licencja_OpenAccess', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='openaccess_tryb_dostepu',
            field=models.ForeignKey(on_delete=models.CASCADE, blank=True, to='bpp.Tryb_OpenAccess_Wydawnictwo_Zwarte', null=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='wydawnictwo_zwarte',
            name='openaccess_wersja_tekstu',
            field=models.ForeignKey(on_delete=models.CASCADE, blank=True, to='bpp.Wersja_Tekstu_OpenAccess', null=True),
            preserve_default=True,
        ),
    ]



# -*- coding: utf-8 -*-


from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0025_auto_20150830_1740'),
    ]

    operations = [
        migrations.AlterField(
            model_name='praca_doktorska',
            name='autor',
            field=models.ForeignKey(on_delete=models.CASCADE, to='bpp.Autor', unique=True),
            preserve_default=True,
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='autor',
            field=models.ForeignKey(on_delete=models.CASCADE, to='bpp.Autor', unique=True),
            preserve_default=True,
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-19 10:42
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0091_charakter_pbn_dla_typu_kbn'),
    ]

    operations = [
        migrations.AddField(
            model_name='uczelnia',
            name='pokazuj_status_korekty',
            field=models.BooleanField(default=True, verbose_name='Pokazuj status korekty na stronie rekordu'),
        ),
        migrations.AlterField(
            model_name='charakter_pbn',
            name='wlasciwy_dla',
            field=models.CharField(choices=[('article', 'Artykuł'), ('book', 'Książka'), ('chapter', 'Rozdział')], max_length=20, verbose_name='Właściwy dla...'),
        ),
    ]



import json

from django.utils.safestring import mark_safe


def format_json(obj, fld_name):
    result = ""
    if obj:
        result = json.dumps(getattr(obj, fld_name), indent=4, sort_keys=True)
        result_str = f"<pre>{result}</pre>"
        result = mark_safe(result_str)
    return result



import pytest
from model_bakery import baker

from bpp.models import Wydawnictwo_Zwarte


@pytest.fixture
def wydawnictwo_nadrzedne(wydawnictwo_zwarte):
    """Zwraca nowe wydawnictwo, bedace nadrzednym dla domyslnej fikstury wydawnictwa zwartego."""
    wn = baker.make(Wydawnictwo_Zwarte)
    wydawnictwo_zwarte.wydawnictwo_nadrzedne_id = wn.pk
    wydawnictwo_zwarte.save(update_fields=["wydawnictwo_nadrzedne_id"])
    return wn



from django.urls import path, register_converter

from raport_slotow.converters import DecimalPathConverter
from raport_slotow.views import (
    ListaRaportSlotowUczelnia,
    ParametryRaportSlotowEwaluacja,
    RaportSlotow,
    RaportSlotowEwaluacja,
    RaportSlotowZerowy,
    RouterRaportuSlotowUczelnia,
    SzczegolyRaportSlotowUczelnia,
    SzczegolyRaportSlotowUczelniaListaRekordow,
    UtworzRaportSlotowUczelnia,
    WyborOsoby,
    WygenerujPonownieRaportSlotowUczelnia,
)
from raport_slotow.views.upowaznienie_pbn import (
    ParametryRaportEwaluacjaUpowaznienia,
    RaportEwaluacjaUpowaznienia,
)

register_converter(DecimalPathConverter, "decimal")

app_name = "raport_slotow"

urlpatterns = [
    path("raport-slotow-autor/", WyborOsoby.as_view(), name="index"),
    path(
        r"raport-slotow-autor/wyswietl/",
        RaportSlotow.as_view(),
        name="raport",
    ),
    path(
        "raport-slotow-uczelnia/",
        ListaRaportSlotowUczelnia.as_view(),
        name="lista-raport-slotow-uczelnia",
    ),
    path(
        "raport-slotow-uczelnia/new/",
        UtworzRaportSlotowUczelnia.as_view(),
        name="utworz-raport-slotow-uczelnia",
    ),
    path(
        "raport-slotow-uczelnia/<uuid:pk>/",
        RouterRaportuSlotowUczelnia.as_view(),
        name="raportslotowuczelnia-router",
    ),
    path(
        "raport-slotow-uczelnia/<uuid:pk>/details/",
        SzczegolyRaportSlotowUczelnia.as_view(),
        name="raportslotowuczelnia-details",
    ),
    path(
        "raport-slotow-uczelnia/<uuid:pk>/regen/",
        WygenerujPonownieRaportSlotowUczelnia.as_view(),
        name="raportslotowuczelnia-regen",
    ),
    path(
        "raport-slotow-uczelnia/<uuid:pk>/results/",
        SzczegolyRaportSlotowUczelniaListaRekordow.as_view(),
        name="raportslotowuczelnia-results",
    ),
    path(
        "raport-slotow-ewaluacja/",
        ParametryRaportSlotowEwaluacja.as_view(),
        name="index-ewaluacja",
    ),
    path(
        r"raport-slotow-ewaluacja/raport/",
        RaportSlotowEwaluacja.as_view(),
        name="raport-ewaluacja",
    ),
    path(
        "raport-ewaluacja-upowaznienia/",
        ParametryRaportEwaluacjaUpowaznienia.as_view(),
        name="index-upowaznienia",
    ),
    path(
        r"raport-ewaluacja-upowaznienia/raport/",
        RaportEwaluacjaUpowaznienia.as_view(),
        name="raport-ewaluacja-upowaznienia",
    ),
    path(
        "raport-slotow-zerowy/",
        RaportSlotowZerowy.as_view(),
        name="raport-slotow-zerowy",
    ),
    path(
        "raport-slotow-zerowy/5/",
        RaportSlotowZerowy.as_view(min_pk=5),
        name="raport-slotow-zerowy-bez-5",
    ),
]



import pytest

from import_pracownikow.tests.conftest import (
    import_pracownikow_factory,
    testdata_xls_path_factory,
)

from bpp.models import Autor, Autor_Jednostka


def test_ImportPracownikow_perform(import_pracownikow):
    import_pracownikow.perform()
    assert import_pracownikow.importpracownikowrow_set.count() == 1
    assert import_pracownikow.importpracownikowrow_set.first().zmiany_potrzebne
    assert Autor_Jednostka.objects.count() == 1

    import_pracownikow.mark_reset()
    import_pracownikow.perform()
    assert not import_pracownikow.importpracownikowrow_set.first().zmiany_potrzebne


def test_ImportPracownikow_perform_aktualizacja_tytulu_nastapila(
    import_pracownikow, tytuly
):
    import_pracownikow.perform()
    assert Autor.objects.get(pk=50).tytul.skrot == "lek. med."


@pytest.mark.django_db
def test_ImportPracownikow_perform_aktualizacja_tytulu_brakujacy_tytul(
    baza_importu_pracownikow, admin_user
):
    ip = import_pracownikow_factory(
        admin_user, testdata_xls_path_factory("_nieistn_tytul")
    )

    ip.perform()
    assert Autor.objects.get(pk=50).tytul is None


def test_ImportPracownikow_brak_naglowka(import_pracownikow_brak_naglowka):
    import_pracownikow_brak_naglowka.perform()
    assert import_pracownikow_brak_naglowka.importpracownikowrow_set.count() == 0



from decimal import Decimal

from dal import autocomplete
from dal_select2.fields import Select2ListCreateChoiceField
from django import forms
from django.db.models.fields import BLANK_CHOICE_DASH
from django.forms.widgets import HiddenInput

from django.contrib import admin

from bpp.jezyk_polski import warianty_zapisanego_nazwiska
from bpp.models import (
    Autor,
    Dyscyplina_Naukowa,
    Jednostka,
    Typ_Odpowiedzialnosci,
    Uczelnia,
)

# Proste tabele


class BaseBppAdminMixin:
    """Ta klasa jest potrzebna, (XXXżeby działały sygnały post_commit.XXX)

    Ta klasa KIEDYŚ była potrzebna, obecnie niespecjalnie. Aczkolwiek,
    zostawiam ją z przyczyn historycznych, w ten sposób można łatwo
    wyłowić klasy edycyjne, które grzebią COKOLWIEK w cache.
    """

    # Mój dynks do grappelli
    auto_open_collapsibles = True

    # ograniczenie wielkosci listy
    list_per_page = 50


def get_first_typ_odpowiedzialnosci():
    return Typ_Odpowiedzialnosci.objects.filter(skrot="aut.").first()


def generuj_formularz_dla_autorow(
    baseModel, include_rekord=False, include_dyscyplina=True
):
    class baseModel_AutorForm(forms.ModelForm):

        if include_rekord:
            rekord = forms.ModelChoiceField(
                widget=HiddenInput, queryset=baseModel.rekord.get_queryset()
            )

        autor = forms.ModelChoiceField(
            queryset=Autor.objects.all(),
            widget=autocomplete.ModelSelect2(url="bpp:autor-autocomplete"),
        )

        jednostka = forms.ModelChoiceField(
            queryset=Jednostka.objects.all(),
            widget=autocomplete.ModelSelect2(url="bpp:jednostka-autocomplete"),
        )

        if include_dyscyplina:
            dyscyplina_naukowa = forms.ModelChoiceField(
                queryset=Dyscyplina_Naukowa.objects.all(),
                widget=autocomplete.ModelSelect2(
                    forward=["autor", "rok"],
                    url="bpp:dyscyplina-naukowa-przypisanie-autocomplete",
                ),
                required=False,
            )

        zapisany_jako = Select2ListCreateChoiceField(
            choice_list=[],
            widget=autocomplete.Select2(
                url="bpp:zapisany-jako-autocomplete", forward=["autor"]
            ),
        )

        typ_odpowiedzialnosci = forms.ModelChoiceField(
            queryset=Typ_Odpowiedzialnosci.objects.all(),
            initial=get_first_typ_odpowiedzialnosci,
        )

        def __init__(self, *args, **kwargs):
            super().__init__(*args, **kwargs)

            # Ustaw inicjalną wartość dla pola 'afiliuje'
            domyslnie_afiliuje = True
            uczelnia = Uczelnia.objects.first()
            if uczelnia is not None:
                domyslnie_afiliuje = uczelnia.domyslnie_afiliuje
            self.fields["afiliuje"].initial = domyslnie_afiliuje

            # Nowy rekord
            instance = kwargs.get("instance")
            data = kwargs.get("data")
            if not data and not instance:
                # Jeżeli nie ma na czym pracowac
                return

            initial = None

            if instance:
                autor = instance.autor
                initial = instance.zapisany_jako

            if data:
                # "Nowe" dane z formularza przyszły
                zapisany_jako = data.get(kwargs["prefix"] + "-zapisany_jako")
                if not zapisany_jako:
                    return

                try:
                    autor = Autor.objects.get(pk=int(data[kwargs["prefix"] + "-autor"]))
                except Autor.DoesNotExist:

                    class autor:
                        imiona = "TakiAutor"
                        nazwisko = "NieIstnieje"
                        poprzednie_nazwiska = ""

            warianty = warianty_zapisanego_nazwiska(
                autor.imiona, autor.nazwisko, autor.poprzednie_nazwiska
            )
            warianty = list(warianty)

            if initial not in warianty and instance is not None:
                warianty.append(instance.zapisany_jako)

            self.initial["zapisany_jako"] = initial

            self.fields["zapisany_jako"] = Select2ListCreateChoiceField(
                choice_list=list(warianty),
                initial=initial,
                widget=autocomplete.Select2(
                    url="bpp:zapisany-jako-autocomplete", forward=["autor"]
                ),
            )

        class Media:
            js = ["/static/bpp/js/autorform_dependant.js"]

        class Meta:
            DATA_OSWIADCZENIA = "data_oswiadczenia"

            fields = [
                "autor",
                "jednostka",
                "typ_odpowiedzialnosci",
                "zapisany_jako",
                "afiliuje",
                "zatrudniony",
                "upowaznienie_pbn",
                "procent",
                "profil_orcid",
                DATA_OSWIADCZENIA,
                "kolejnosc",
            ]

            if include_dyscyplina:
                data_oswiadczenia_idx = fields.index(DATA_OSWIADCZENIA)
                fields = (
                    fields[:data_oswiadczenia_idx]
                    + [
                        "dyscyplina_naukowa",
                        "przypieta",
                    ]
                    + fields[data_oswiadczenia_idx:]
                )

            if include_rekord:
                fields = [
                    "rekord",
                ] + fields

            model = baseModel
            widgets = {"kolejnosc": HiddenInput, "rekord": HiddenInput}

    return baseModel_AutorForm


def generuj_inline_dla_autorow(baseModel, include_dyscyplina=True):
    class baseModel_AutorFormset(forms.BaseInlineFormSet):
        def clean(self):
            # get forms that actually have valid data
            percent = Decimal("0.00")
            for form in self.forms:
                try:
                    if form.cleaned_data:
                        percent += form.cleaned_data.get(
                            "procent", Decimal("0.00")
                        ) or Decimal("0.00")
                except AttributeError:
                    # annoyingly, if a subform is invalid Django explicity raises
                    # an AttributeError for cleaned_data
                    pass
            if percent > Decimal("100.00"):
                raise forms.ValidationError(
                    "Liczba podanych procent odpowiedzialności przekracza 100.0"
                )

    baseClass = admin.StackedInline
    extraRows = 0

    from django.conf import settings

    if getattr(settings, "INLINE_DLA_AUTOROW", "stacked") == "tabular":
        baseClass = admin.TabularInline
        extraRows = 1

    class baseModel_AutorInline(baseClass):
        model = baseModel
        extra = extraRows
        form = generuj_formularz_dla_autorow(
            baseModel, include_rekord=False, include_dyscyplina=include_dyscyplina
        )
        formset = baseModel_AutorFormset
        sortable_field_name = "kolejnosc"
        sortable_excludes = [
            "typ_odpowiedzialnosci",
            "zapisany_jako",
            "afiliuje",
        ]

        # Maksymalna ilosć autorów edytowanych w ramach formularza. Pozostałych
        # autorów nalezy edytować przez opcję "Edycja autorów"
        max_num = 25

    return baseModel_AutorInline


#
# Kolumny ze skrótami
#


class KolumnyZeSkrotamiMixin:
    def charakter_formalny__skrot(self, obj):
        return obj.charakter_formalny.skrot

    charakter_formalny__skrot.short_description = "Char. form."
    charakter_formalny__skrot.admin_order_field = "charakter_formalny__skrot"

    def typ_kbn__skrot(self, obj):
        return obj.typ_kbn.skrot

    typ_kbn__skrot.short_description = "Typ KBN"
    typ_kbn__skrot.admin_order_field = "typ_kbn__skrot"


class RestrictDeletionToAdministracjaGroupMixin:
    def get_action_choices(self, request, default_choices=BLANK_CHOICE_DASH):
        if "administracja" in [x.name for x in request.user.cached_groups]:
            return admin.ModelAdmin.get_action_choices(self, request, default_choices)
        return []

    def has_delete_permission(self, request, obj=None):
        if "administracja" in [x.name for x in request.user.cached_groups]:
            return admin.ModelAdmin.has_delete_permission(self, request, obj=obj)
        return False


class RestrictDeletionToAdministracjaGroupAdmin(
    RestrictDeletionToAdministracjaGroupMixin, admin.ModelAdmin
):
    pass


class PreventDeletionMixin:
    def has_delete_permission(self, request, obj=None):
        return False

    def get_action_choices(self, request, default_choices=BLANK_CHOICE_DASH):
        return []


class PreventDeletionAdmin(PreventDeletionMixin, admin.ModelAdmin):
    pass



from django.urls import path

from ewaluacja2021 import views

app_name = "ewaluacja2021"

urlpatterns = [
    path("", views.ListaImportow.as_view(), name="lista-importow"),
    path("<int:pk>/", views.SzczegolyImportu.as_view(), name="szczegoly-importu"),
    path("new/", views.NowyImport.as_view(), name="nowy-imporrt"),
    path("3n/", views.ListaRaporto3N.as_view(), name="lista-raportow3n"),
    path(
        "3n/<int:pk>/", views.SzczegolyRaportu3N.as_view(), name="szczegoly-raportu3n"
    ),
    path(
        "3n/<int:pk>/plik/",
        views.PlikRaportu3N.as_view(),
        name="szczegoly-raportu-3n-plik",
    ),
    path(
        "3n/<int:pk>/wykres/",
        views.WykresRaportu3N.as_view(),
        name="szczegoly-raportu-3n-wykres",
    ),
    path("3n/new/", views.NowyRaport3N.as_view(), name="nowy-raport3n"),
]



# Generated by Django 3.2.14 on 2022-07-07 22:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("bpp", "0323_jednostka_pokazuj_opis"),
    ]

    operations = [
        migrations.DeleteModel(
            name="Kronika_Patent_View",
        ),
        migrations.DeleteModel(
            name="Kronika_Praca_Doktorska_View",
        ),
        migrations.DeleteModel(
            name="Kronika_Praca_Habilitacyjna_View",
        ),
        migrations.DeleteModel(
            name="Kronika_View",
        ),
        migrations.DeleteModel(
            name="Kronika_Wydawnictwo_Ciagle_View",
        ),
        migrations.DeleteModel(
            name="Kronika_Wydawnictwo_Zwarte_View",
        ),
        migrations.AlterField(
            model_name="autor",
            name="orcid_w_pbn",
            field=models.BooleanField(
                help_text="Jeżeli ORCID jest w bazie PBN, to pole powinno być zaznaczone. Zaznaczenie następuje\n        automatycznie, przez procedury integrujące bazę danych z PBNem w nocy. Można też zaznaczyć ręcznie.\n        Pole wykorzystywane jest gdy autor nie ma odpowiednika w PBN (pole 'PBN UID' rekordu autora jest puste,\n        zaś eksport danych powoduje komunikat zwrotny z PBN o nieistniejącym w ich bazie ORCID). W takich sytuacjach\n        należy w polu wybrać \"Nie\". ",  # noqa
                null=True,
                verbose_name="ORCID jest w bazie PBN?",
            ),
        ),
        migrations.AlterField(
            model_name="autor_jednostka",
            name="podstawowe_miejsce_pracy",
            field=models.BooleanField(null=True),
        ),
        migrations.AlterField(
            model_name="bppuser",
            name="first_name",
            field=models.CharField(
                blank=True, max_length=150, verbose_name="first name"
            ),
        ),
        migrations.AlterField(
            model_name="patent",
            name="cached_punkty_dyscyplin",
            field=models.JSONField(blank=True, editable=False, null=True),
        ),
        migrations.AlterField(
            model_name="patent",
            name="wdrozenie",
            field=models.BooleanField(null=True, verbose_name="Wdrożenie"),
        ),
        migrations.AlterField(
            model_name="praca_doktorska",
            name="opl_pub_amount",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Kwota (zł)",
            ),
        ),
        migrations.AlterField(
            model_name="praca_doktorska",
            name="opl_pub_cost_free",
            field=models.BooleanField(null=True, verbose_name="Publikacja bezkosztowa"),
        ),
        migrations.AlterField(
            model_name="praca_doktorska",
            name="opl_pub_other",
            field=models.BooleanField(null=True, verbose_name="Inne środki finansowe"),
        ),
        migrations.AlterField(
            model_name="praca_doktorska",
            name="opl_pub_research_or_development_projects",
            field=models.BooleanField(
                help_text="Środki finansowe przyznane na realizację projektu w zakresie badań naukowych lub prac rozwojowych",  # noqa
                null=True,
                verbose_name="Środki finansowe na realizację projektu",
            ),
        ),
        migrations.AlterField(
            model_name="praca_doktorska",
            name="opl_pub_research_potential",
            field=models.BooleanField(
                help_text="Środki finansowe, o których mowa w art. 365 pkt 2 ustawy",
                null=True,
                verbose_name="Środki finansowe art. 365 pkt 2 ustawy",
            ),
        ),
        migrations.AlterField(
            model_name="praca_habilitacyjna",
            name="opl_pub_amount",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Kwota (zł)",
            ),
        ),
        migrations.AlterField(
            model_name="praca_habilitacyjna",
            name="opl_pub_cost_free",
            field=models.BooleanField(null=True, verbose_name="Publikacja bezkosztowa"),
        ),
        migrations.AlterField(
            model_name="praca_habilitacyjna",
            name="opl_pub_other",
            field=models.BooleanField(null=True, verbose_name="Inne środki finansowe"),
        ),
        migrations.AlterField(
            model_name="praca_habilitacyjna",
            name="opl_pub_research_or_development_projects",
            field=models.BooleanField(
                help_text="Środki finansowe przyznane na realizację projektu w zakresie badań naukowych lub prac rozwojowych",  # noqa
                null=True,
                verbose_name="Środki finansowe na realizację projektu",
            ),
        ),
        migrations.AlterField(
            model_name="praca_habilitacyjna",
            name="opl_pub_research_potential",
            field=models.BooleanField(
                help_text="Środki finansowe, o których mowa w art. 365 pkt 2 ustawy",
                null=True,
                verbose_name="Środki finansowe art. 365 pkt 2 ustawy",
            ),
        ),
        migrations.AlterField(
            model_name="wydawca",
            name="lista_poziomow",
            field=models.JSONField(blank=True, editable=False, null=True),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="cached_punkty_dyscyplin",
            field=models.JSONField(blank=True, editable=False, null=True),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_amount",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Kwota (zł)",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_cost_free",
            field=models.BooleanField(null=True, verbose_name="Publikacja bezkosztowa"),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_other",
            field=models.BooleanField(null=True, verbose_name="Inne środki finansowe"),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_research_or_development_projects",
            field=models.BooleanField(
                help_text="Środki finansowe przyznane na realizację projektu w zakresie badań naukowych lub prac rozwojowych",  # noqa
                null=True,
                verbose_name="Środki finansowe na realizację projektu",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_ciagle",
            name="opl_pub_research_potential",
            field=models.BooleanField(
                help_text="Środki finansowe, o których mowa w art. 365 pkt 2 ustawy",
                null=True,
                verbose_name="Środki finansowe art. 365 pkt 2 ustawy",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="cached_punkty_dyscyplin",
            field=models.JSONField(blank=True, editable=False, null=True),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_amount",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=20,
                null=True,
                verbose_name="Kwota (zł)",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_cost_free",
            field=models.BooleanField(null=True, verbose_name="Publikacja bezkosztowa"),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_other",
            field=models.BooleanField(null=True, verbose_name="Inne środki finansowe"),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_research_or_development_projects",
            field=models.BooleanField(
                help_text="Środki finansowe przyznane na realizację projektu w zakresie badań naukowych lub prac rozwojowych",  # noqa
                null=True,
                verbose_name="Środki finansowe na realizację projektu",
            ),
        ),
        migrations.AlterField(
            model_name="wydawnictwo_zwarte",
            name="opl_pub_research_potential",
            field=models.BooleanField(
                help_text="Środki finansowe, o których mowa w art. 365 pkt 2 ustawy",
                null=True,
                verbose_name="Środki finansowe art. 365 pkt 2 ustawy",
            ),
        ),
    ]



from pbn_api.admin.base import BasePBNAPIAdminNoReadonly
from pbn_api.admin.helpers import format_json
from pbn_api.models import SentData

from django.contrib import admin


@admin.register(SentData)
class SentDataAdmin(BasePBNAPIAdminNoReadonly):

    list_display = [
        "object",
        "last_updated_on",
        "typ_rekordu",
        "pbn_uid_id",
        "uploaded_okay",
        "exception_details",
    ]
    ordering = ("-last_updated_on",)
    search_fields = ["data_sent", "exception"]
    readonly_fields = [
        "content_type",
        "object_id",
        "last_updated_on",
        "uploaded_okay",
        "exception",
        "pbn_uid_id",
        "typ_rekordu",
    ]
    fields = readonly_fields + ["pretty_json"]
    list_filter = ["uploaded_okay", "typ_rekordu"]

    list_per_page = 25

    def wyslij_ponownie(self, request, qset):
        from bpp.admin.helpers import sprobuj_wgrac_do_pbn

        for elem in qset:
            obj = elem.object
            sprobuj_wgrac_do_pbn(request, obj)

    wyslij_ponownie.short_description = "Wyślij ponownie (tylko błędne)"

    def wyslij_ponownie_force(self, request, qset):
        from bpp.admin.helpers import sprobuj_wgrac_do_pbn

        for elem in qset:
            obj = elem.object
            sprobuj_wgrac_do_pbn(request, obj, force_upload=True)

    wyslij_ponownie_force.short_description = (
        "Wyślij ponownie (wszystko; wymuś ponowny transfer)"
    )

    actions = [wyslij_ponownie, wyslij_ponownie_force]

    def has_delete_permission(self, request, *args, **kw):
        return True

    def has_add_permission(self, request):
        return False

    def has_change_permission(self, request, obj=None):
        return False

    def pretty_json(self, obj=None):
        return format_json(obj, "data_sent")

    pretty_json.short_description = "Wysłane dane"

    def exception_details(self, obj):
        if obj.exception:
            try:
                return obj.exception.split('"details":')[1][:-3]
            except BaseException:
                return obj.exception

    exception_details.short_description = "Opis problemu"
    exception_details.admin_order_field = "exception"



# -*- coding: utf-8 -*-
# Generated by Django 1.11.10 on 2018-03-05 13:36
from __future__ import unicode_literals

from django.db import migrations, models

from bpp.migration_util import load_custom_sql


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0119_pola_patentow'),
    ]

    operations = [
        # Zostaną utworzone ponownie w następnej migracji, a ich
        # obecność przeszkadzała będzie modyfikacji pola kc_impact_factor
        # dla poniższych tabel:

        migrations.RunSQL("DROP VIEW bpp_patent_view CASCADE"),
        migrations.RunSQL("DROP VIEW bpp_wydawnictwo_ciagle_view CASCADE"),
        migrations.RunSQL("DROP VIEW bpp_wydawnictwo_zwarte_view  CASCADE"),
        migrations.RunSQL("DROP VIEW bpp_praca_doktorska_view CASCADE"),
        migrations.RunSQL("DROP VIEW bpp_praca_habilitacyjna_view CASCADE"),

        migrations.RunSQL("DROP VIEW bpp_nowe_sumy_patent_view CASCADE"),
        migrations.RunSQL("DROP VIEW bpp_nowe_sumy_wydawnictwo_ciagle_view CASCADE"),
        migrations.RunSQL("DROP VIEW bpp_nowe_sumy_wydawnictwo_zwarte_view CASCADE"),
        migrations.RunSQL("DROP VIEW bpp_nowe_sumy_praca_doktorska_view CASCADE"),
        migrations.RunSQL("DROP VIEW bpp_nowe_sumy_praca_habilitacyjna_view CASCADE"),

        migrations.AlterField(
            model_name='patent',
            name='kc_impact_factor',
            field=models.DecimalField(blank=True, db_index=True, decimal_places=3, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa tego raportu.', max_digits=6, null=True, verbose_name='KC: Impact factor'),
        ),
        migrations.AlterField(
            model_name='praca_doktorska',
            name='kc_impact_factor',
            field=models.DecimalField(blank=True, db_index=True, decimal_places=3, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa tego raportu.', max_digits=6, null=True, verbose_name='KC: Impact factor'),
        ),
        migrations.AlterField(
            model_name='praca_habilitacyjna',
            name='kc_impact_factor',
            field=models.DecimalField(blank=True, db_index=True, decimal_places=3, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa tego raportu.', max_digits=6, null=True, verbose_name='KC: Impact factor'),
        ),
        migrations.AlterField(
            model_name='punktacja_zrodla',
            name='kc_impact_factor',
            field=models.DecimalField(blank=True, db_index=True, decimal_places=3, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa tego raportu.', max_digits=6, null=True, verbose_name='KC: Impact factor'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_ciagle',
            name='kc_impact_factor',
            field=models.DecimalField(blank=True, db_index=True, decimal_places=3, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa tego raportu.', max_digits=6, null=True, verbose_name='KC: Impact factor'),
        ),
        migrations.AlterField(
            model_name='wydawnictwo_zwarte',
            name='kc_impact_factor',
            field=models.DecimalField(blank=True, db_index=True, decimal_places=3, default=None, help_text='Jeżeli wpiszesz\n        wartość w to pole, to zostanie ona użyta w raporcie dla Komisji\n        Centralnej w punkcie IXa tego raportu.', max_digits=6, null=True, verbose_name='KC: Impact factor'),
        ),

        # Wczytaj ponownie ostatnie poprawne widoki
        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("0103_widoki_nowe_sumy")
        ),

        migrations.RunPython(
            lambda *args, **kw: load_custom_sql("108_bpp_nowe_sumy_view_bug")
        )
    ]



import pytest
from django.urls import reverse
from model_bakery import baker

from zglos_publikacje.models import (
    Obslugujacy_Zgloszenia_Wydzialow,
    Zgloszenie_Publikacji,
)

from django.contrib.auth.models import Group

from bpp.const import GR_ZGLOSZENIA_PUBLIKACJI
from bpp.core import zgloszenia_publikacji_emails
from bpp.models import BppUser

EMAIL = "test@panie.random.lol.pl"


@pytest.mark.django_db
def test_pierwsza_strona_wymagaj_pliku(webtest_app, uczelnia):
    url = reverse("zglos_publikacje:nowe_zgloszenie")
    page = webtest_app.get(url)
    page.forms[0]["0-tytul_oryginalny"] = "123"
    page.forms[0]["0-rok"] = "2020"
    page.forms[0][
        "0-rodzaj_zglaszanej_publikacji"
    ] = Zgloszenie_Publikacji.Rodzaje.ARTYKUL_LUB_MONOGRAFIA
    page.forms[0]["0-email"] = "123@123.pl"

    page2 = page.forms[0].submit()
    assert page2.status_code == 200
    assert b"Plik" in page2.content


@pytest.mark.django_db
def test_pierwsza_strona_nie_wymagaj_pliku(webtest_app, uczelnia):
    url = reverse("zglos_publikacje:nowe_zgloszenie")
    page = webtest_app.get(url)
    page.forms[0]["0-tytul_oryginalny"] = "123"
    page.forms[0]["0-strona_www"] = "https://onet.pl"
    page.forms[0]["0-rok"] = "2020"
    page.forms[0]["0-email"] = "123@123.pl"

    page2 = page.forms[0].submit()
    assert page2.status_code == 200
    assert b"Plik" not in page2.content


def test_druga_strona(
    webtest_app,
    wprowadzanie_danych_user,
    typy_odpowiedzialnosci,
    uczelnia,
    django_capture_on_commit_callbacks,
):
    assert zgloszenia_publikacji_emails()

    url = reverse("zglos_publikacje:nowe_zgloszenie")
    page = webtest_app.get(url)
    page.forms[0]["0-tytul_oryginalny"] = "123"
    page.forms[0]["0-rok"] = "2020"
    page.forms[0][
        "0-rodzaj_zglaszanej_publikacji"
    ] = Zgloszenie_Publikacji.Rodzaje.ARTYKUL_LUB_MONOGRAFIA
    page.forms[0]["0-strona_www"] = "https://onet.pl/"
    page.forms[0]["0-email"] = "123@123.pl"

    page2 = page.forms[0].submit()

    page3 = page2.forms[0].submit()

    page3.forms[0]["3-opl_pub_cost_free"] = "true"

    with django_capture_on_commit_callbacks(execute=True):  # as callbacks:
        page4 = page3.forms[0].submit().maybe_follow()

    assert b"powiadomiony" in page4.content
    from django.core import mail

    assert len(mail.outbox) == 1


@pytest.mark.django_db
def test_zglos_publikacje_bez_pliku_artykul(
    webtest_app, uczelnia, typy_odpowiedzialnosci
):
    url = reverse("zglos_publikacje:nowe_zgloszenie")
    page = webtest_app.get(url)
    page.forms[0]["0-tytul_oryginalny"] = "123"
    page.forms[0][
        "0-rodzaj_zglaszanej_publikacji"
    ] = Zgloszenie_Publikacji.Rodzaje.ARTYKUL_LUB_MONOGRAFIA

    page.forms[0]["0-strona_www"] = "https://onet.pl"
    page.forms[0]["0-rok"] = "2020"
    page.forms[0]["0-email"] = "123@123.pl"

    # Lista autorow
    page2 = page.forms[0].submit()

    # Dane o platnosciach
    page3 = page2.forms[0].submit()
    page3.forms[0]["3-opl_pub_cost_free"] = "true"

    # Sukces!
    page4 = page3.forms[0].submit().maybe_follow()

    assert b"zostanie zaakceptowane" in page4.content


@pytest.mark.django_db
def test_zglos_publikacje_bez_pliku_nie_artykul(
    webtest_app, uczelnia, typy_odpowiedzialnosci
):
    url = reverse("zglos_publikacje:nowe_zgloszenie")
    page = webtest_app.get(url)
    page.forms[0]["0-tytul_oryginalny"] = "123"
    page.forms[0][
        "0-rodzaj_zglaszanej_publikacji"
    ] = Zgloszenie_Publikacji.Rodzaje.POZOSTALE

    page.forms[0]["0-strona_www"] = "https://onet.pl"
    page.forms[0]["0-rok"] = "2020"
    page.forms[0]["0-email"] = "123@123.pl"

    # Lista autorow
    page2 = page.forms[0].submit()

    # Sukces!
    page3 = page2.forms[0].submit().maybe_follow()

    assert b"zostanie zaakceptowane" in page3.content


def zrob_submit_calego_formularza(
    webtest_app, django_capture_on_commit_callbacks, autor=None, jednostka=None
):

    url = reverse("zglos_publikacje:nowe_zgloszenie")
    page = webtest_app.get(url)
    page.forms[0]["0-tytul_oryginalny"] = "123"
    page.forms[0]["0-rok"] = "2020"
    page.forms[0][
        "0-rodzaj_zglaszanej_publikacji"
    ] = Zgloszenie_Publikacji.Rodzaje.ARTYKUL_LUB_MONOGRAFIA
    page.forms[0]["0-strona_www"] = "https://onet.pl/"
    page.forms[0]["0-email"] = "123@123.pl"

    page2 = page.forms[0].submit()

    if autor is not None:
        page2.forms[0]["2-0-autor"].force_value(autor.pk)
        page2.forms[0]["2-0-jednostka"].force_value(jednostka.pk)

    page3 = page2.forms[0].submit()
    # page3.showbrowser()

    page3.forms[0]["3-opl_pub_cost_free"] = "true"

    with django_capture_on_commit_callbacks(execute=True):  # as callbacks:
        page4 = page3.forms[0].submit().maybe_follow()

    assert b"powiadomiony" in page4.content


def test_wysylanie_maili_brak_ludzi_w_bazie(
    webtest_app,
    django_capture_on_commit_callbacks,
    typy_odpowiedzialnosci,
    uczelnia,
    wydzial,
    jednostka,
):
    from django.core import mail

    zrob_submit_calego_formularza(webtest_app, django_capture_on_commit_callbacks)

    assert len(mail.outbox) == 0

    # Bo nie było do kogo wysłać


def test_wysylanie_maili_trafi_do_grupy_zglaszanie_publikacji(
    webtest_app,
    django_capture_on_commit_callbacks,
    normal_django_user,
    typy_odpowiedzialnosci,
    uczelnia,
    wydzial,
    jednostka,
):
    normal_django_user.email = EMAIL
    normal_django_user.save()

    normal_django_user.groups.add(
        Group.objects.get_or_create(name=GR_ZGLOSZENIA_PUBLIKACJI)[0]
    )

    from django.core import mail

    zrob_submit_calego_formularza(webtest_app, django_capture_on_commit_callbacks)
    assert len(mail.outbox) == 1
    assert mail.outbox[0].to == [
        EMAIL,
    ]


def test_wysylanie_maili_obslugujacym_zgloszenia(
    webtest_app,
    django_capture_on_commit_callbacks,
    typy_odpowiedzialnosci,
    uczelnia,
    wydzial,
    aktualna_jednostka,
    autor_jan_kowalski,
):
    inny_user = baker.make(BppUser, email=EMAIL)
    Obslugujacy_Zgloszenia_Wydzialow.objects.create(user=inny_user, wydzial=wydzial)

    zrob_submit_calego_formularza(
        webtest_app,
        django_capture_on_commit_callbacks,
        autor=autor_jan_kowalski,
        jednostka=aktualna_jednostka,
    )

    from django.core import mail

    assert len(mail.outbox) == 1
    assert mail.outbox[0].to == [inny_user.email]



# -*- coding: utf-8 -*-


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bpp', '0048_wyczysc_nazwy_jednostek'),
    ]

    operations = [
        migrations.AlterField(
            model_name='autor',
            name='pesel_md5',
            field=models.CharField(max_length=32, blank=True, help_text=b'Hash MD5 numeru PESEL', null=True, verbose_name=b'PESEL MD5', db_index=True),
        ),
    ]



# -*- encoding: utf-8 -*-
from datetime import datetime

from django.core.management import BaseCommand
from django.db import transaction
import sys
from bpp.models import cache


class Command(BaseCommand):
    help = 'Odbudowuje cache'

    def handle(self, *args, **options):
        from xml.etree import ElementTree
        import requests

        url = "http://bpp.umlub.pl:9080/bpp/oai/oai-pmh-repository.xml"
        params = {
            'verb': "ListRecords",
            'metadataPrefix': "oai_dc",
            'from': "2000-01-01T00:00:00Z",
            'until': "2020-01-01T00:00:00Z"
        }

        start = datetime.now()

        res = requests.get(url, params=params)
        print(res.content)
        
        while True:

            try:
                r = ElementTree.XML(res.content)
            except Exception as e:
                print(res.content)
                raise e

            try:
                resumptionToken = r.getchildren()[2].getchildren()[-1].text
            except IndexError:
                break

            delta = datetime.now() - start
            seconds = float(delta.seconds + delta.microseconds/1000000.0)

            print('\r', resumptionToken[:20], "response len: ", len(res.content), "response time: ", delta, "b/s: ", ("%.2f" % (len(res.content)/seconds)), end=' ')
            sys.stdout.flush()
            #print "%r" %  r.getchildren()[2].getchildren()[0][1].getchildren()[0].getchildren()[0].text[:78]

            newParams= {
                'verb': "ListRecords",
                "resumptionToken": resumptionToken
            }
            params['resumptionToken'] = resumptionToken

            start = datetime.now()
            res = requests.get(url, params=newParams)



# Generated by Django 3.0.11 on 2021-03-08 07:46

from decimal import Decimal

import django.core.validators
from django.db import migrations, models

import bpp.models.uczelnia


class Migration(migrations.Migration):

    dependencies = [
        ("raport_slotow", "0008_auto_20210308_0839"),
    ]

    operations = [
        migrations.AlterField(
            model_name="raportslotowuczelnia",
            name="akcja",
            field=models.CharField(
                choices=[
                    (
                        "slot",
                        "zbieraj najkorzystniejsze prace do zadanej wielkości slotu",
                    ),
                    ("wszystko", "wyeksportuj wszystkie prace"),
                ],
                default="slot",
                max_length=10,
            ),
        ),
        migrations.AlterField(
            model_name="raportslotowuczelnia",
            name="do_roku",
            field=models.IntegerField(
                default=bpp.models.uczelnia.UczelniaManager.do_roku_default
            ),
        ),
        migrations.AlterField(
            model_name="raportslotowuczelnia",
            name="slot",
            field=models.DecimalField(
                blank=True,
                decimal_places=4,
                default=Decimal("1"),
                max_digits=7,
                null=True,
                validators=[django.core.validators.MaxValueValidator(20)],
            ),
        ),
    ]



from dal import autocomplete
from djangoql.admin import DjangoQLSearchMixin
from import_export import resources
from import_export.admin import ExportMixin
from import_export.fields import Field

from django.contrib import admin

from bpp.admin.filters import (
    OrcidAutoraDyscyplinyObecnyFilter,
    PBN_UID_IDAutoraObecnyFilter,
)
from bpp.models import Autor, Autor_Dyscyplina


class Autor_DyscyplinaResource(resources.ModelResource):
    def get_queryset(self):

        return (
            super()
            .get_queryset()
            .select_related("autor")
            .prefetch_related("dyscyplina_naukowa", "subdyscyplina_naukowa")
        )

    rodzaj_autora = Field()

    def dehydrate_rodzaj_autora(self, ad):
        return Autor_Dyscyplina.RODZAJE_AUTORA[ad.rodzaj_autora]

    def dehydrate_autor__pbn_uid_id(self, ad):
        if ad.autor.pbn_uid_id:
            return str(ad.autor.pbn_uid_id)
        return None

    class Meta:

        model = Autor_Dyscyplina

        fields = (
            "autor__nazwisko",
            "autor__imiona",
            "rok",
            "rodzaj_autora",
            "wymiar_etatu",
            "autor__pbn_uid_id",
            "autor__orcid",
            "dyscyplina_naukowa__nazwa",
            "dyscyplina_naukowa__kod",
            "procent_dyscypliny",
            "subdyscyplina_naukowa__nazwa",
            "subdyscyplina_naukowa__kod",
            "procent_subdyscypliny",
        )
        export_order = fields


from django import forms


class Autor_DyscyplinaForm(forms.ModelForm):
    autor = forms.ModelChoiceField(
        queryset=Autor.objects.all(),
        widget=autocomplete.ModelSelect2(url="bpp:autor-autocomplete"),
    )

    class Meta:
        model = Autor_Dyscyplina
        fields = "__all__"


class Autor_DyscyplinaAdmin(DjangoQLSearchMixin, ExportMixin, admin.ModelAdmin):
    djangoql_completion_enabled_by_default = True
    djangoql_completion = True

    resource_class = Autor_DyscyplinaResource
    form = Autor_DyscyplinaForm

    list_filter = [
        "rok",
        "dyscyplina_naukowa",
        "subdyscyplina_naukowa",
        "rodzaj_autora",
        "wymiar_etatu",
        OrcidAutoraDyscyplinyObecnyFilter,
        PBN_UID_IDAutoraObecnyFilter,
    ]
    list_display = [
        "autor",
        "rok",
        "rodzaj_autora",
        "wymiar_etatu",
        "pbn_uid_id",
        "orcid",
        "dyscyplina_naukowa",
        "procent_dyscypliny",
        "subdyscyplina_naukowa",
        "procent_subdyscypliny",
    ]
    ordering = ("autor", "rok")

    def orcid(self, obj):
        return obj.autor.orcid

    orcid.admin_order_field = "autor__orcid"

    def pbn_uid_id(self, obj):
        return obj.autor.pbn_uid_id

    pbn_uid_id.admin_order_field = "autor__pbn_uid_id"
    pbn_uid_id.short_description = "PBN UID autora"


admin.site.register(Autor_Dyscyplina, Autor_DyscyplinaAdmin)



# Generated by Django 3.0.11 on 2021-02-28 12:41

import uuid

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models

import long_running.models
import long_running.notification_mixins


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="ImportPracownikow",
            fields=[
                (
                    "id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("created_on", models.DateTimeField(auto_now_add=True)),
                ("last_updated_on", models.DateTimeField(auto_now=True)),
                ("started_on", models.DateTimeField(blank=True, null=True)),
                ("finished_on", models.DateTimeField(blank=True, null=True)),
                ("finished_successfully", models.BooleanField(default=False)),
                ("traceback", models.TextField(blank=True, null=True)),
                ("plik_xls", models.FileField(upload_to="")),
                (
                    "owner",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "ordering": ["-last_updated_on"],
                "abstract": False,
            },
            bases=(
                long_running.notification_mixins.ASGINotificationMixin,
                long_running.models.NullNotificationMixin,
                models.Model,
            ),
        ),
    ]
